# coding=utf-8
"""
Convenience functions to manage logging
"""
from elib.custom_logging._custom_logging_handler import CustomLoggingHandler
from ._custom_logging import get_logger, set_handler_level, get_elib_logger, \
    set_root_logger, get_root_logger
